@@ -1,5 +1,10 @@
+from cProfile import Profile
+
 import numpy as np
 
+from ..classes.profile import ProfileHandler
+from ..resources.language import Text
+
 
 def load(path, type):
 
@@ -11,7 +16,9 @@ def load(path, type):
     if type == "pdd":
         direction = "Z"
     else:
-        direction = "X- oder Y"
+        direction = "X- {} Y".format(
+            Text().orr[ProfileHandler().get_attribute("language")]
+        )
 
     if path.endswith(".txt"):
         data = np.loadtxt(path, unpack=True)
