@@ -9,7 +9,6 @@ Created on Thu Dec 16 12:47:50 2021
 
 import os
 import tkinter as tk
-import tkinter.ttk as ttk
 
 from .src.classes.main_viewer import MainApplication
 
@@ -17,21 +16,18 @@ from .src.classes.main_viewer import MainApplication
 def topasgraphsim():
 
     root = tk.Tk()
-    root.geometry(f"{root.winfo_screenwidth()//2}x{root.winfo_screenheight()//2}+0+0")
-    root.title("Simulationsauswertung")
+    # Center the window
+    screen_width = root.winfo_screenwidth()
+    screen_height = root.winfo_screenheight()
+    width = screen_width / 2
+    height = screen_height / 2
+    x = screen_width / 2 - width / 2
+    y = screen_height / 2 - height / 2
+    root.geometry("%dx%d+%d+%d" % (width, height, x, y))
     root.iconbitmap(
         str(os.path.dirname(os.path.realpath(__file__)) + "\\src\\resources\\icon.ico")
     )
-    style = ttk.Style(root)
-    root.tk.call(
-        "source",
-        str(
-            os.path.dirname(os.path.realpath(__file__))
-            + "\\src\\Azure-ttk-theme\\azure.tcl"
-        ),
-    )
-    root.tk.call("set_theme", "light")
-    Main = MainApplication(root)
+    MainApplication(root, root.winfo_geometry())
     root.mainloop()
 
 
